@@ -2,7 +2,7 @@ package DBIx::Skinny::Schema::Loader;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use Carp;
 use DBI;
@@ -111,7 +111,7 @@ sub make_schema_at {
             columns => $self->{ impl }->table_columns($_),
         },
         $options->{ table_template }
-    ) for @{ $self->{ impl }->tables };
+    ) for @{ $self->_get_tables($options->{ ignore_rules }) };
     $schema .= $self->_insert_template($options->{ after_template });
     $schema .= "1;";
     return $schema;
@@ -141,6 +141,19 @@ sub _make_install_table_text {
     return $template;
 }
 
+sub _get_tables {
+    my ($self, $ignore_rules) = @_;
+    my @tables;
+    for my $table ( @{ $self->{ impl }->tables } ) {
+        my $ignore;
+        for my $rule ( @$ignore_rules ) {
+            $ignore++ and last if $table =~ $rule;
+        }
+        push @tables, $table unless $ignore;
+    }
+    return \@tables;
+}
+
 1;
 __END__
 
@@ -360,6 +373,12 @@ C<make_schema_at> replaces some following variables.
 [% pk %]      ... primary keys joined by a space
 [% columns %] ... columns joined by a space
 
+=head2 ignore_rules
+
+you can exclude tables that matching any rules declared in ignore_rules from the schema.
+
+  ignore_rules => [ qr/rs$/, qr/^no/ ],
+
 =head1 LAZY SCHEMA LOADING
 
 if you write Your::DB class without setup sentence,
